==> apache-beam-2.58.1-source-release.zip: beam-2.58.1/sdks/java/io/solace/src/test/java/org/apache/beam/sdk/io/solace/MockEmptySessionService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.io.solace;

import org.apache.beam.sdk.io.solace.broker.MessageReceiver;
import org.apache.beam.sdk.io.solace.broker.SessionService;

public class MockEmptySessionService implements SessionService {

  String exceptionMessage = "This is an empty client, use a MockSessionService instead.";

  @Override
  public void close() {
    throw new UnsupportedOperationException(exceptionMessage);
  }

  @Override
  public boolean isClosed() {
    throw new UnsupportedOperationException(exceptionMessage);
  }

  @Override
  public MessageReceiver createReceiver() {
    throw new UnsupportedOperationException(exceptionMessage);
  }

  @Override
  public void connect() {
    throw new UnsupportedOperationException(exceptionMessage);
  }
}

==> apache-beam-2.60.0-source-release.zip: beam-2.60.0/sdks/java/io/solace/src/test/java/org/apache/beam/sdk/io/solace/MockEmptySessionService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.beam.sdk.io.solace;

import com.solacesystems.jcsmp.JCSMPProperties;
import org.apache.beam.sdk.io.solace.broker.MessageReceiver;
import org.apache.beam.sdk.io.solace.broker.SessionService;

public class MockEmptySessionService extends SessionService {

  String exceptionMessage = "This is an empty client, use a MockSessionService instead.";

  @Override
  public void close() {
    throw new UnsupportedOperationException(exceptionMessage);
  }

  @Override
  public boolean isClosed() {
    throw new UnsupportedOperationException(exceptionMessage);
  }

  @Override
  public MessageReceiver createReceiver() {
    throw new UnsupportedOperationException(exceptionMessage);
  }

  @Override
  public void connect() {
    throw new UnsupportedOperationException(exceptionMessage);
  }

  @Override
  public JCSMPProperties initializeSessionProperties(JCSMPProperties baseProperties) {
    throw new UnsupportedOperationException(exceptionMessage);
  }
}
